Gerenciando seus casos de suporte IBM Cloud de forma eficaz
Saiba como gerenciar seus casos de suporte em IBM Cloud, incluindo o acompanhamento do progresso, a atualização de casos e o gerenciamento de listas de observação para a resolução eficaz de problemas.
Para visualizar e gerenciar os seus casos de suporte, acesse a página Gerenciar casos. Se você for um usuário de infraestrutura clássica e não vir uma lista de um caso anterior, clique em Visualizar casos de infraestrutura clássica.
Você também pode obter uma visualização rápida dos seus 5 casos abertos atualizados mais recentemente digitando case status no assistente de IA IBM Cloud.
Você também pode visualizar seus casos de suporte IBM na página Manage cases (Gerenciar casos), mas eles só podem ser gerenciados no portal de suporte IBM. O acesso para visualização desses casos é controlado no portal de suporte IBM. Para obter mais informações sobre acesso, consulte Gerenciamento do acesso à sua conta de suporte.
Visualizando casos de suporte usando a API
É possível visualizar programaticamente um caso de suporte usando a API, conforme mostrado na solicitação de amostra a seguir. Para obter mais informações, consulte a API de Gerenciamento de Casos.
Para visualizar um caso, consulte as amostras a seguir:
curl -X GET 'https://support-center.cloud.ibm.com/case-management/v1/cases/{case_number}?fields=number,updated_at,resources' -H 'Authorization: TOKEN' \
GetCaseOptions getCaseOptions = new GetCaseOptions.Builder()
.caseNumber(caseNumber)
.addFields(GetCaseOptions.Fields.DESCRIPTION)
.addFields(GetCaseOptions.Fields.STATUS)
.addFields(GetCaseOptions.Fields.SEVERITY)
.addFields(GetCaseOptions.Fields.CREATED_BY)
.build();
Response<Case> response = service.getCase(getCaseOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const fieldsToReturn = [
CaseManagementV1.GetCaseConstants.Fields.DESCRIPTION,
CaseManagementV1.GetCaseConstants.Fields.STATUS,
CaseManagementV1.GetCaseConstants.Fields.SEVERITY,
CaseManagementV1.GetCaseConstants.Fields.CREATED_BY,
];
const params = {
caseNumber: caseNumber,
fields: fieldsToReturn,
};
caseManagementService.getCase(params)
.then(res => {
console.log(JSON.stringify(res.result, null, 2));
})
.catch(err => {
console.warn(err)
});
fields_to_return = [
GetCaseEnums.Fields.DESCRIPTION,
GetCaseEnums.Fields.STATUS,
GetCaseEnums.Fields.SEVERITY,
GetCaseEnums.Fields.CREATED_BY,
]
case = case_management_service.get_case(
case_number=case_number,
fields=fields_to_return
).get_result()
print(json.dumps(case, indent=2))
getCaseOptions := caseManagementService.NewGetCaseOptions(
caseNumber,
)
getCaseOptions.SetFields([]string{
casemanagementv1.GetCaseOptionsFieldsDescriptionConst,
casemanagementv1.GetCaseOptionsFieldsStatusConst,
casemanagementv1.GetCaseOptionsFieldsSeverityConst,
casemanagementv1.GetCaseOptionsFieldsCreatedByConst,
})
caseVar, response, err := caseManagementService.GetCase(getCaseOptions)
if err != nil {
panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", " ")
fmt.Println(string(b))
Atualizando casos de suporte usando a API
A solicitação de amostra a seguir mostra como atualizar programaticamente um caso de suporte. Para obter mais informações, consulte a API de Gerenciamento de Casos.
curl -X PUT '/case-management/v1/cases/{case_number}/status' -H 'Authorization: TOKEN' -d '{
"action": "resolve",
"comment": "The issue is resolved. Thank you!",
"resolution_code": 1
}'
ResolvePayload statusPayloadModel = new ResolvePayload.Builder()
.action("resolve")
.comment("The problem has been resolved.")
.resolutionCode(1)
.build();
UpdateCaseStatusOptions updateCaseStatusOptions = new UpdateCaseStatusOptions.Builder()
.caseNumber(caseNumber)
.statusPayload(statusPayloadModel)
.build();
Response<Case> response = service.updateCaseStatus(updateCaseStatusOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const statusPayloadModel = {
action: 'resolve',
comment: 'The problem has been resolved.',
resolution_code: 1,
};
const params = {
caseNumber: caseNumber,
statusPayload: statusPayloadModel,
};
caseManagementService.updateCaseStatus(params)
.then(res => {
console.log(JSON.stringify(res.result, null, 2));
})
.catch(err => {
console.warn(err)
});
status_payload_model = {
'action': 'resolve',
'comment': 'The problem has been resolved.',
'resolution_code': 1,
}
case = case_management_service.update_case_status(
case_number=case_number,
status_payload=status_payload_model
).get_result()
print(json.dumps(case, indent=2))
statusPayloadModel := &casemanagementv1.ResolvePayload{
Action: core.StringPtr("resolve"),
Comment: core.StringPtr("The problem has been resolved."),
ResolutionCode: core.Int64Ptr(int64(1)),
}
updateCaseStatusOptions := caseManagementService.NewUpdateCaseStatusOptions(
caseNumber,
statusPayloadModel,
)
caseVar, response, err := caseManagementService.UpdateCaseStatus(updateCaseStatusOptions)
if err != nil {
panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", " ")
fmt.Println(string(b))
Incluindo comentários nos casos de suporte usando a API
A solicitação de amostra a seguir mostra como incluir programaticamente um comentário a um caso de suporte. Para obter mais informações, consulte a API de Gerenciamento de Casos.
curl -X PUT '/case-management/v1/cases/{case_number}/comments' -H 'Authorization: TOKEN' -d '{
"comment": "Test comment api"
}'
AddCommentOptions addCommentOptions = new AddCommentOptions.Builder()
.caseNumber(caseNumber)
.comment("This is an example comment.")
.build();
Response<Comment> response = service.addComment(addCommentOptions).execute();
Comment comment = response.getResult();
System.out.println(comment);
const params = {
caseNumber: caseNumber,
comment: 'This is an example comment,',
};
caseManagementService.addComment(params)
.then(res => {
console.log(JSON.stringify(res.result, null, 2));
})
.catch(err => {
console.warn(err)
});
comment = case_management_service.add_comment(
case_number=case_number,
comment='This is an example comment.'
).get_result()
print(json.dumps(comment, indent=2))
addCommentOptions := caseManagementService.NewAddCommentOptions(
caseNumber,
"This is an example comment.",
)
comment, response, err := caseManagementService.AddComment(addCommentOptions)
if err != nil {
panic(err)
}
b, _ := json.MarshalIndent(comment, "", " ")
fmt.Println(string(b))
Atualização de casos de suporte
Selecione o número do caso para atualizar o caso de suporte. Você pode adicionar um comentário, anexar ou remover arquivos, adicionar recursos ou atualizar a lista de observação. Para atualizar seu ticket de suporte, siga estas etapas:
- Na barra de menus do console IBM Cloud, clique no ícone Ajuda
> Centro de suporte.
- Selecione o caso de suporte no bloco “Casos de suporte recentes ”.
- Adicione um comentário e clique em Submit (Enviar ).
- Se desejar, você pode atualizar os seguintes campos:
- Adicionar um usuário à lista de observação
- Anexar ou remover arquivos
- Adicionar um recurso específico para um caso de suporte técnico
Adição de um CRN a um comentário de caso
A inclusão de detalhes sobre os recursos específicos relacionados a um caso de suporte permite uma triagem, investigação e resolução mais eficientes. Para visualizar e copiar um nome de recurso de nuvem (CRN) para adicionar a um caso de suporte, siga estas etapas:
- No console do IBM Cloud®, clique no ícone
> Lista de recursos para visualizar sua lista de recursos.
- Expanda as seções para localizar a instância de serviço para a qual você deseja recuperar o CRN.
- Clique na linha da tabela. Essa ação abre o painel lateral da tabela de recursos, onde você pode visualizar o CRN.
- Selecione Copiar para a área de transferência ao lado do valor CRN.
- Cole o valor em um comentário no caso de suporte.
Atualizando a lista de observação do seu caso de suporte
É possível atualizar quais usuários em sua conta podem receber notificações sobre seu caso de suporte, incluindo-os na lista de observação. Os usuários podem ser adicionados à lista de acompanhamento ao criar casos de suporte ou após a criação do caso de suporte.
Por padrão, os usuários da conta não têm acesso para criar, atualizar, procurar ou visualizar casos. O titular da conta deve conceder acesso aos usuários por meio da atribuição de uma política de acesso do Identity and Access Management (IAM). Para obter mais informações, consulte Designando acesso de usuário para trabalhar com casos de suporte.
Para garantir que os usuários sejam notificados sobre atualizações em um caso de suporte existente que você criou, conclua as etapas a seguir para incluí-los na lista de observação.
-
Na barra de menus do console IBM Cloud, clique no ícone Ajuda
> Centro de suporte.
-
Selecione o caso de suporte no bloco “Casos de suporte recentes ”.
-
Na seção “Lista de observação”, clique no ícone “ Configurações ”
.
-
Selecione os usuários que estão na conta para incluir na lista de observação.
Os usuários incluídos na lista de observação devem ser membros da conta na qual o caso foi criado. Para obter mais informações sobre como atribuir acesso de usuários a sua conta, consulte Incluindo usuários em seu grupo de acesso de gerenciamento de caso.
Tipos de status de caso de suporte
Quando sua resposta é necessária para uma atualização de seu caso de suporte, o status é exibido como Waiting on client. Se você não fornecer uma resposta dentro de sete dias, o status será atualizado para Resolved.
O caso será, então, encerrado se ainda não houver resposta após mais sete dias. Para obter uma descrição de cada tipo de status, veja a tabela a seguir:
| Status | Descrição |
|---|---|
| Novo | Um caso criado ainda não visualizado por um engenheiro de suporte. |
| Em andamento | Um caso que está sob revisão. |
| Aguardando o cliente | O engenheiro de suporte enviou uma consulta sobre o caso que requer a resposta do usuário. |
| Resolução fornecida | O engenheiro de suporte forneceu uma resolução que o usuário precisa executar. |
| Resolvido | O caso de suporte é considerado concluído e pronto para ser encerrado. |
| Fechado | O caso é fechado por um engenheiro de suporte e não pode ser reaberto. |
Escalando casos de suporte
Com um plano de suporte pago, você pode utilizar o processo de escalonamento para destacar problemas críticos e expressar suas preocupações em relação a um caso de suporte. Quando um caso é encaminhado, a equipe de suporte IBM Cloud revisa as informações no caso de suporte e responde com atualizações apropriadas. Para obter informações sobre a gravidade do caso, consulte Gravidade de caso e tempos de resposta iniciais.
Para escalar um caso, conclua as etapas a seguir:
- Entre em contato com o suporte IBM Cloud por chat ou por telefone.
- Clique em Launch AI Assistant (Iniciar Assistente de IA ) na Central de Suporte e digite
agentpara se conectar com um agente de suporte - Conecte-se por telefone usando o número no Support Center.
- Clique em Launch AI Assistant (Iniciar Assistente de IA ) na Central de Suporte e digite
- Forneça o seu número de caso existente e uma solicitação para escalar o caso.
- Forneça a justificativa de uma escalação e explique o impacto no negócio do seu problema ou questão.
Planos de suporte básico: Se você tiver um plano de suporte básico, o acesso ao suporte será apenas para casos não técnicos. Se a sua solicitação de suporte exigir uma resposta mais imediata, considere a possibilidade de fazer upgrade para um plano de suporte Premium ou Avançado para que você possa atribuir um nível de gravidade a um caso. Para atualizar seu plano de suporte, crie um ticket na Central de Suporte ou entre em contato com um representante de vendas da IBM Cloud para obter assistência.
Procurando casos de suporte
Na página “Gerenciar casos”, você pode filtrar por status do caso e pesquisar todos os seus casos de suporte usando parâmetros de consulta na barra de pesquisa. Os filtros padrão são definidos para visualizar apenas os casos abertos. Para visualizar os casos resolvidos ou encerrados, atualize o filtro de status. Todos os parâmetros podem ser usados em conjunto e inseridos em qualquer ordem. Você também pode filtrar os casos selecionando Todos os casos, Meus casos e Casos da lista de observação.
Veja a tabela a seguir para obter detalhes sobre os parâmetros de procura:
| Parâmetro | Opção | Regra |
|---|---|---|
number |
número do caso de destino | Esse parâmetro não pode ser usado com outros parâmetros. Quando o parâmetro number é usado, todos os outros parâmetros e opções são ignorados. O parâmetro number não faz autopreenchimento na procura. Deve-se usar
o número do caso integral para iniciar a procura. |
sort |
número assunto gravidade atualizado em |
Somente uma das opções sort pode ser usada a cada vez. É possível usar o prefixo ~ para reverter a ordem de classificação. |
status |
novo inProgress waitingOnClient resolutionProvided resolvido fechado |
Qualquer número de opções pode ser usado. As opções disponíveis podem ser inseridas como status:new,inProgress ou como status:new status:inProgress. |
page |
página de destino a visualizar | Se você tiver vários resultados de sua pesquisa em várias páginas, poderá visualizá-los em qualquer página de resultado. Por exemplo, para visualizar a página 5 de 10, use page:5. |
pageSize |
10 25 50 100 |
O tamanho da página a ser visualizada. O tamanho da página refere-se ao número de resultados que você deseja carregar. |
Se você inserir um termo sem um parâmetro, os resultados da procura serão mostrados para o número do caso de suporte e o assunto do caso.
Exemplos de consulta e de URL
Você pode inserir consultas de pesquisa na barra de pesquisa indicando um parâmetro e uma opção separados por dois pontos (:) ou pode usar parâmetros no link “ URL ” para acessar diretamente um caso específico ou um grupo de casos na página “Gerenciar casos ”.
Para usar parâmetros no URL, adicione um ponto de interrogação (?) ao final do URL. Em seguida, configure seu parâmetro igual à opção selecionada. Você também pode separar parâmetros adicionais com o símbolo “&”.
Para procurar um caso por palavra-chave, é possível inserir a palavra na barra de procura sem um parâmetro. Para procurar uma palavra-chave com a URL, use search como parâmetro e configure-a igual à sua palavra-chave, por exemplo,
search=server.
Procurando por número do caso
Insira o seguinte para procurar casos de suporte pelo número do caso:
- Consultar
number:CS1234567- URL
https://cloud.ibm.com/unifiedsupport/cases?number=CS1234567
Procurando com vários parâmetros
É possível que você queira procurar pelos casos de suporte novos e em andamento, limitar os resultados a 25 por página e exibi-los por severidade. Você também sabe que o caso que está procurando não vai estar entre as primeiras páginas, portanto, deseja começar na página cinco. Insira a consulta de procura a seguir:
- Consultar
status:new,inProgress page:5 pageSize:25 sort:severity- URL
https://cloud.ibm.com/unifiedsupport/cases?status=new&status=inProgress&pageSize=25&sort=severity
Procurando casos resolvidos
Insira a consulta a seguir para visualizar todos os casos resolvidos com base na última vez em que foram atualizados:
- Consultar
sort:~updatedAT status:resolved- URL
https://cloud.ibm.com/unifiedsupport/cases?sort=~updatedAT&status=resolved
Receber notificações de casos abertos usando um perfil confiável
Quando estiver trabalhando com um perfil confiável e abrir um caso de suporte, você poderá escolher entre duas opções para receber notificações.
Opção 1: As notificações podem ser enviadas para seu endereço de e-mail.
Opção 2: As notificações podem ser enviadas para o endereço de e-mail associado ao perfil confiável.
Para usar a segunda opção, um endereço de e-mail deve ser associado ao perfil confiável que não seja uma ID de serviço, um recurso de nuvem ou um recurso de computador.